@@ -1,5 +1,5 @@
 package Perl::Critic::Policy::HTTPCookies;
-$Perl::Critic::Policy::HTTPCookies::VERSION = '0.51';
+$Perl::Critic::Policy::HTTPCookies::VERSION = '0.52';
 use strict;
 use warnings;
 
@@ -78,7 +78,7 @@ Perl::Critic::Policy::HTTPCookies - Avoid using HTTP::Cookies
 
 =head1 VERSION
 
-version 0.51
+version 0.52
 
 =head1 DESCRIPTION
 
@@ -87,7 +87,7 @@ L<< HTTP::Cookies >>.
 
 HTTP::Cookies takes a very lenient approach to setting cookies that does
 not work well with today's Internet:
-L<< https://github.com/gisle/http-cookies/pull/7 >>
+L<< https://github.com/libwww-perl/http-cookies/pull/7 >>
 
 Consider using L<< HTTP::CookieJar >> or L<< HTTP::CookieJar::LWP >>
 instead.
